@@ -14,41 +14,40 @@
 # limitations under the License.
 #
 
-from google.auth.transport.requests import AuthorizedSession  # type: ignore
-import json  # type: ignore
-import grpc  # type: ignore
-from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth import credentials as ga_credentials  # type: ignore
-from google.api_core import exceptions as core_exceptions
-from google.api_core import retry as retries
-from google.api_core import rest_helpers
-from google.api_core import rest_streaming
-from google.api_core import path_template
-from google.api_core import gapic_v1
-
-from google.protobuf import json_format
-from google.api_core import operations_v1
-from requests import __version__ as requests_version
 import dataclasses
+import json  # type: ignore
 import re
 from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
+from google.api_core import (
+    gapic_v1,
+    operations_v1,
+    path_template,
+    rest_helpers,
+    rest_streaming,
+)
+from google.api_core import exceptions as core_exceptions
+from google.api_core import retry as retries
+from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.transport.grpc import SslCredentials  # type: ignore
+from google.auth.transport.requests import AuthorizedSession  # type: ignore
+from google.protobuf import json_format
+import grpc  # type: ignore
+from requests import __version__ as requests_version
+
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 
-from google.cloud.gke_multicloud_v1.types import azure_resources
-from google.cloud.gke_multicloud_v1.types import azure_service
 from google.longrunning import operations_pb2  # type: ignore
 
-from .base import (
-    AzureClustersTransport,
-    DEFAULT_CLIENT_INFO as BASE_DEFAULT_CLIENT_INFO,
-)
+from google.cloud.gke_multicloud_v1.types import azure_resources, azure_service
 
+from .base import AzureClustersTransport
+from .base import DEFAULT_CLIENT_INFO as BASE_DEFAULT_CLIENT_INFO
 
 DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
     gapic_version=BASE_DEFAULT_CLIENT_INFO.gapic_version,
@@ -72,117 +71,133 @@ class AzureClustersRestInterceptor:
 
     .. code-block:: python
         class MyCustomAzureClustersInterceptor(AzureClustersRestInterceptor):
-            def pre_create_azure_client(request, metadata):
+            def pre_create_azure_client(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_create_azure_client(response):
+            def post_create_azure_client(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_create_azure_cluster(request, metadata):
+            def pre_create_azure_cluster(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_create_azure_cluster(response):
+            def post_create_azure_cluster(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_create_azure_node_pool(request, metadata):
+            def pre_create_azure_node_pool(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_create_azure_node_pool(response):
+            def post_create_azure_node_pool(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_delete_azure_client(request, metadata):
+            def pre_delete_azure_client(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_delete_azure_client(response):
+            def post_delete_azure_client(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_delete_azure_cluster(request, metadata):
+            def pre_delete_azure_cluster(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_delete_azure_cluster(response):
+            def post_delete_azure_cluster(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_delete_azure_node_pool(request, metadata):
+            def pre_delete_azure_node_pool(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_delete_azure_node_pool(response):
+            def post_delete_azure_node_pool(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_generate_azure_access_token(request, metadata):
+            def pre_generate_azure_access_token(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_generate_azure_access_token(response):
+            def post_generate_azure_access_token(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_get_azure_client(request, metadata):
+            def pre_get_azure_client(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_get_azure_client(response):
+            def post_get_azure_client(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_get_azure_cluster(request, metadata):
+            def pre_get_azure_cluster(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_get_azure_cluster(response):
+            def post_get_azure_cluster(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_get_azure_node_pool(request, metadata):
+            def pre_get_azure_node_pool(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_get_azure_node_pool(response):
+            def post_get_azure_node_pool(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_get_azure_server_config(request, metadata):
+            def pre_get_azure_server_config(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_get_azure_server_config(response):
+            def post_get_azure_server_config(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_list_azure_clients(request, metadata):
+            def pre_list_azure_clients(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_list_azure_clients(response):
+            def post_list_azure_clients(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_list_azure_clusters(request, metadata):
+            def pre_list_azure_clusters(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_list_azure_clusters(response):
+            def post_list_azure_clusters(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_list_azure_node_pools(request, metadata):
+            def pre_list_azure_node_pools(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_list_azure_node_pools(response):
+            def post_list_azure_node_pools(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_update_azure_cluster(request, metadata):
+            def pre_update_azure_cluster(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_update_azure_cluster(response):
+            def post_update_azure_cluster(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
-            def pre_update_azure_node_pool(request, metadata):
+            def pre_update_azure_node_pool(self, request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
 
-            def post_update_azure_node_pool(response):
+            def post_update_azure_node_pool(self, response):
                 logging.log(f"Received response: {response}")
+                return response
 
         transport = AzureClustersRestTransport(interceptor=MyCustomAzureClustersInterceptor())
         client = AzureClustersClient(transport=transport)
@@ -590,10 +605,10 @@ class AzureClustersRestTransport(AzureClustersTransport):
         self,
         *,
         host: str = "gkemulticloud.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
-        credentials_file: str = None,
-        scopes: Sequence[str] = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
@@ -710,6 +725,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
                 credentials=self._credentials,
                 scopes=self._scopes,
                 http_options=http_options,
+                path_prefix="v1",
             )
 
             self._operations_client = operations_v1.AbstractOperationsClient(
@@ -740,7 +756,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
             request: azure_service.CreateAzureClientRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> operations_pb2.Operation:
             r"""Call the create azure client method over HTTP.
@@ -840,7 +856,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
             request: azure_service.CreateAzureClusterRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> operations_pb2.Operation:
             r"""Call the create azure cluster method over HTTP.
@@ -940,7 +956,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
             request: azure_service.CreateAzureNodePoolRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> operations_pb2.Operation:
             r"""Call the create azure node pool method over HTTP.
@@ -1038,7 +1054,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
             request: azure_service.DeleteAzureClientRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> operations_pb2.Operation:
             r"""Call the delete azure client method over HTTP.
@@ -1127,7 +1143,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
             request: azure_service.DeleteAzureClusterRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> operations_pb2.Operation:
             r"""Call the delete azure cluster method over HTTP.
@@ -1216,7 +1232,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
             request: azure_service.DeleteAzureNodePoolRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> operations_pb2.Operation:
             r"""Call the delete azure node pool method over HTTP.
@@ -1305,7 +1321,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
             request: azure_service.GenerateAzureAccessTokenRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> azure_service.GenerateAzureAccessTokenResponse:
             r"""Call the generate azure access
@@ -1396,7 +1412,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
             request: azure_service.GetAzureClientRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> azure_resources.AzureClient:
             r"""Call the get azure client method over HTTP.
@@ -1500,7 +1516,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
             request: azure_service.GetAzureClusterRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> azure_resources.AzureCluster:
             r"""Call the get azure cluster method over HTTP.
@@ -1588,7 +1604,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
             request: azure_service.GetAzureNodePoolRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> azure_resources.AzureNodePool:
             r"""Call the get azure node pool method over HTTP.
@@ -1676,7 +1692,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
             request: azure_service.GetAzureServerConfigRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> azure_resources.AzureServerConfig:
             r"""Call the get azure server config method over HTTP.
@@ -1768,7 +1784,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
             request: azure_service.ListAzureClientsRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> azure_service.ListAzureClientsResponse:
             r"""Call the list azure clients method over HTTP.
@@ -1858,7 +1874,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
             request: azure_service.ListAzureClustersRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> azure_service.ListAzureClustersResponse:
             r"""Call the list azure clusters method over HTTP.
@@ -1948,7 +1964,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
             request: azure_service.ListAzureNodePoolsRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> azure_service.ListAzureNodePoolsResponse:
             r"""Call the list azure node pools method over HTTP.
@@ -2040,7 +2056,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
             request: azure_service.UpdateAzureClusterRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> operations_pb2.Operation:
             r"""Call the update azure cluster method over HTTP.
@@ -2140,7 +2156,7 @@ class AzureClustersRestTransport(AzureClustersTransport):
             request: azure_service.UpdateAzureNodePoolRequest,
             *,
             retry: OptionalRetry = gapic_v1.method.DEFAULT,
-            timeout: float = None,
+            timeout: Optional[float] = None,
             metadata: Sequence[Tuple[str, str]] = (),
         ) -> operations_pb2.Operation:
             r"""Call the update azure node pool method over HTTP.
